==> aroundme_0_6_0.zip: aroundme_0_6_0/aroundme/language/1/barnraiser_01/grp_rsp.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'grp_common.lang.php');


//HEADER
$lang['hdr_menu'] = 							"menu";
$lang['hdr_rsp'] = 								"Really Simple Publishing (Group home page)";
$lang['hdr_blogs'] = 							"blogs";
$lang['hdr_activities'] = 						"activities";
$lang['hdr_group_library'] = 					"wiki pages";
$lang['hdr_subjects'] = 						"subjects";
$lang['hdr_files'] = 							"files";
$lang['hdr_polls'] = 							"polls";
$lang['hdr_tasks'] = 							"tasks";


//ERROR
$lang['err_no_items'] = 						"Sorry, there are no items available for publishing";


//ICONS
$lang['ttl_sticky'] = 							"S";
$lang['ttl_remove'] = 							"R";
$lang['ttl_live'] = 							"L";
$lang['ttl_hold'] = 							"H";
$lang['ttl_pending'] = 							"P";


$lang['txt_sticky'] = 							"sticky";
$lang['txt_all'] = 								"all";
$lang['txt_remove'] = 							"remove";
$lang['txt_live'] = 							"live";
$lang['txt_hold'] = 							"hold";
$lang['txt_pending'] = 							"pending";
$lang['txt_intro'] = 							"The Really Simple Publishing (RSP) allows you to publish items to your groups home page.";

?>

==> aroundme_0_6_6.zip: aroundme_0_6_6/aroundme/language/1/barnraiser_01/grp_rsp.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

//HEADER
$lang['hdr_menu'] = 							"menu";
$lang['hdr_rsp'] = 								"Really Simple Publishing (Group home page)";
$lang['hdr_blogs'] = 							"blogs";
$lang['hdr_activities'] = 						"activities";
$lang['hdr_library'] = 							"wiki pages";
$lang['hdr_subjects'] = 						"subjects";
$lang['hdr_files'] = 							"files";
$lang['hdr_polls'] = 							"polls";
$lang['hdr_tasks'] = 							"tasks";


//ERROR
$lang['err_no_items'] = 						"Sorry, there are no items available for publishing";


//ICONS
$lang['ttl_sticky'] = 							"S";
$lang['ttl_remove'] = 							"R";
$lang['ttl_live'] = 							"L";
$lang['ttl_hold'] = 							"H";
$lang['ttl_pending'] = 							"P";


$lang['txt_sticky'] = 							"sticky";
$lang['txt_all'] = 								"all";
$lang['txt_remove'] = 							"remove";
$lang['txt_live'] = 							"live";
$lang['txt_hold'] = 							"hold";
$lang['txt_pending'] = 							"pending";
$lang['txt_intro'] = 							"The Really Simple Publishing (RSP) allows you to publish items to your groups home page.";

?>
